==> 0.2.3%2B2.tar.gz: lib/viltage.dart <==
library viltage;

import 'dart:html';
import 'dart:collection';
import 'dart:async';
import 'package:crypto/crypto.dart';

part 'etc/gamejolt.dart';
part 'entity/viltage_animation.dart';
part 'etc/utility.dart';
part 'entity/state.dart';
part 'entity/char_node.dart';
part 'entity/entity.dart';
part 'input.dart';
part 'screen.dart';
part 'viltage_config.dart';

class VilTAGE {
	num width, height, updatePS;
	String backgroundColor;
	String backgroundChar;
	String fontName;
	int fontSize;
	bool italic;
	int offX, offY;
	
	CanvasElement ce, ceUnvisible;
	VilTAGEScreen _screen;
	StreamController updateController;
	StreamController focusedController;
	Stream onUpdate;
	Stream onFocused;
	
	bool shouldEnd = false;
	
	VilTAGEConfig vtc;
	
	VilTAGE(this.vtc) {
		vtc.calculate();    
		
		window.onBlur.listen(blured);
		window.onFocus.listen(focused);
		window.onLoad.listen(focused);
		
		width = vtc.width;
		height= vtc.height;
		updatePS = vtc.updatePS;
		backgroundColor = vtc.backgroundColor;
		backgroundChar = vtc.backgroundChar;
		fontSize = vtc.fontSize;
		fontName = vtc.fontName;
		italic = vtc.italic;

		ce = vtc.ce;
		ceUnvisible = new CanvasElement();
		ceUnvisible.width = ce.width;
		ceUnvisible.height = ce.height;
		
		charArray = new List<List<CharNode>>(height);
		ce.children.clear();
		
		for(int i = 0; i < height; i++) {
			charArray[i] = new List<CharNode>(width);
		}

		_screen = new VilTAGEScreen(this);

		Input.init();
		
		focusedController = new StreamController();
		onFocused = focusedController.stream;
		updateController = new StreamController();
		onUpdate = updateController.stream;
		
		loop(1);
		
		blured(null);
		focused(null);
	}
	
	end() {
	  shouldEnd = true;
	}
	
	setScreen(VilTAGEScreen s) {
		Entity.clearScreen (_screen);
		_screen.hide();
		_screen = s;
		_screen.show();
	}
	
	VilTAGEScreen getScreen() {
		return _screen;
	}
	
	List<List<CharNode>> charArray;
	num delta = 0;
	num time1 = 0;
	num pauseState = 1;
	
	void loop(num newDelta) {
		if (pauseState != 1) {
			if (pauseState == 2) { 
				time1 = 0.01;
				pauseState = 0;
			} else {
				time1 += (newDelta - delta) / 1000;
			}
			
			while(time1 >= 1 / updatePS) {
			  calculate();
			  ceUnvisible.context2D.fillStyle = backgroundColor;
			  ceUnvisible.context2D.fillRect(0, 0, ce.width, ce.height);
        ceUnvisible.context2D.font="${italic?"italic":""} ${fontSize}px ${fontName}";
				updateController.add(time1);

			  Input.load();
				if(_screen != null) {
					Utility.update(_screen.entities, time1);
					_screen.update(time1);
				}

				if(_screen != null) {
					Utility.render(_screen.entities, charArray);
					_screen.render();
				}
				Utility.draw(ce.context2D, ceUnvisible.context2D, offX, offY, this);
				
				time1 -= 1 / updatePS;
				Input.end();
			}
			
			delta = newDelta;
		}

		if(!shouldEnd) window.animationFrame.then(loop);
	}
	
	calculate() {
	  vtc.width = width;
	  vtc.height = height;
	  
    vtc.calculate();

    offX = vtc.offX.floor();
    offY = vtc.offY.floor();
	}
	
	blured(Event e) {
		pauseState = 1;
	}
	
	focused(Event e) {
		pauseState = 2;
		focusedController.add(0);
	}
}

==> 0.3.5%2B2.tar.gz: lib/viltage.dart <==
library viltage;

import 'dart:html';
import 'dart:collection';
import 'dart:async';
import 'package:crypto/crypto.dart';

part 'etc/gamejolt.dart';
part 'entity/viltage_animation.dart';
part 'etc/utility.dart';
part 'entity/state.dart';
part 'entity/collidable.dart';
part 'entity/nodes/char_node.dart';
part 'entity/nodes/img_node.dart';
part 'entity/nodes/node.dart';
part 'entity/entity.dart';
part 'etc/input.dart';
part 'screen.dart';
part 'viltage_config.dart';
part 'etc/sound.dart';
part 'premade/fpscounter.dart';


class VilTAGE {
  Input input;
	num width, height, updatePS;
	String backgroundColor;
	String backgroundChar;
	String fontName;
	int fontSize;
	bool italic, bold;
	int offX, offY;
	
	CanvasElement ce;
	VilTAGEScreen _screen;
	StreamController updateController;
	StreamController focusedController;
	Stream onUpdate;
	Stream onFocused;
	
	VilTAGE(VilTAGEConfig vtc) {
		window.onBlur.listen(blured);
		window.onFocus.listen(focused);
		window.onLoad.listen(focused);
		
		ce = vtc.ce;
		
		width = vtc.width;
		height= vtc.height;
		updatePS = vtc.updatePS;
		backgroundColor = vtc.backgroundColor;
		backgroundChar = vtc.backgroundChar;
		fontSize = vtc.fontSize;
		fontName = vtc.fontName;
		italic = vtc.italic;
		bold = vtc.bold;

		
    ce.width = vtc.canvasWidth;
    ce.height = vtc.canvasHeight;
    offX = (vtc.canvasWidth/width).floor();
    offY = (vtc.canvasHeight/height).floor();
		
		nodeArray = new List<List<Node>>(height);
		ce.children.clear();
    ce.context2D.imageSmoothingEnabled=false;
		
		for(int i = 0; i < height; i++) {
			nodeArray[i] = new List<Node>(width);
		}

		_screen = new VilTAGEScreen(this);

		input = new Input();
		
		focusedController = new StreamController();
		onFocused = focusedController.stream;
		updateController = new StreamController();
		onUpdate = updateController.stream;
		
		loop(1);
		
		blured(null);
		focused(null);
		
		Entity.clear(_screen);
	}
	
	setScreen(VilTAGEScreen s) {
    _screen.hide();
    s.entities = _screen.entities;
    _screen = s;
    Entity.clear(_screen);
    _screen.show();
    Utility.render(_screen.entities, nodeArray);
	}
	
	VilTAGEScreen getScreen() {
	  return _screen;
	}
	
	List<List<Node>> nodeArray;
	num delta = 0;
	num time1 = 0;
	num pauseState = 1;
	
	void loop(num newDelta) {
		if (pauseState != 1) {
			if (pauseState == 2) { 
				time1 = 0.001;
				pauseState = 0;
	      delta = newDelta;
			} else {
				time1 += (newDelta - delta) / 1000;
			}
			
			while(time1 >= 1 / updatePS) {
				updateController.add(time1);

			  input.load();
				if(_screen != null) {
					Utility.update(_screen, time1);
					_screen.update(time1);
				}

				if(_screen != null) {
					Utility.render(_screen.entities, nodeArray);
					_screen.render();
				}
				Utility.draw(ce.context2D, offX, offY, this);
				
				time1 -= 1 / updatePS;
				input.end();
			}
			
			delta = newDelta;
		}

		window.animationFrame.then(loop);
	}
	
	blured(Event e) {
		pauseState = 1;
	}
	
	focused(Event e) {
		pauseState = 2;
		focusedController.add(0);
	}
}
